@@ -480,7 +480,7 @@ class DAG:
         # How positionals are resolved is determined by sels.sig
         # The result is the initial ``scope`` the func nodes will both read from
         # to get their arguments, and write their outputs to.
-        scope = self.sig.kwargs_from_args_and_kwargs(args, kwargs)
+        scope = self.sig.kwargs_from_args_and_kwargs(args, kwargs, apply_defaults=True)
         # Go through self.func_nodes in order and call them on scope (performing said
         # read_input -> call_func -> write_output operations)
         self.call_on_scope(scope)
@@ -789,7 +789,7 @@ class DAG:
         A word of warning though: The function index is provided as a convenience, but
         using identifiers is preferable since referencing via the function object
         depends on the other functions of the DAG, so could change if we add nodes.
-        
+
         """
         d = dict()
         for func_node in self.func_nodes:
